SWDEV-339657 - Update catch codes with correct coordinates (#2735)

Change-Id: I8ca78d770a742bf6c2abede494759caa923fcc19
This commit is contained in:
ROCm CI Service Account
2022-06-15 23:28:10 +05:30
committed by GitHub
parent 3e7a9bb177
commit 0cf0ead620
8 changed files with 19 additions and 19 deletions
@@ -43,7 +43,7 @@ template<typename T>
__global__ void normalizedValTextureTest(unsigned int numElements,
float* pDst) {
#if !defined(__HIP_NO_IMAGE_SUPPORT) || !__HIP_NO_IMAGE_SUPPORT
unsigned int elementID = hipThreadIdx_x;
unsigned int elementID = threadIdx.x;
if (elementID >= numElements)
return;
float coord = elementID/static_cast<float>(numElements);